<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Прокси приложения</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адрес</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Необязательный</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Установите флажок &quot;Использовать прокси&quot; в контекстном меню приложения после настройки</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неверный IP-адрес</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Неверный порт</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Отключить</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Вы уверены, что хотите удалить эту конфигурацию?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Проводное соединение %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступа</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Беспроводное соединение %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE соединение %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Новый VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Тип VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Прокси приложения</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Личная точка доступа</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Детали сети</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системный прокси</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Авиарежим</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Проводной сетевой адаптер</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Добавить сетевое подключение</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Адаптер беспроводной сети</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Подключиться к скрытой сети</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Создать PPPoE-соединение</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Статус VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Создать VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Импортировать VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL-адрес конфигурации</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адрес</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступа</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Создать точку доступа</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфейс</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Диапазон</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основной DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска сети</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорость</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Авиарежим</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Недопустимый DNS-адрес</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не связывать</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-адрес устройства</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Клонированный MAC-Адрес</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Настроить MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Основной</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Основной</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Имя уже существует.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Авто-Подключение</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступа</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Добавить настройки</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Создать точку доступа</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP-адрес</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неверный IP-адрес</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Неверная маска сети</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска сети</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неверный IP-адрес</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адрес</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Применяется только на соответствующих ресурсах</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска сети</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Неверный IP-адрес</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Неверная маска сети</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Детали сети</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системный прокси</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Прокси приложения</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Авиарежим</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Детали сети</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Настроить с помощью Network Manager</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Личная точка доступа</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Служба</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Отказ EAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Отказ PAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Отказ CHAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Отказ MSCHAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Отказ MSCHAPv2-аутентификации</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Без сжатия данных BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Без сжатия данных Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без сжатия заголовка TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Без сжатия поля протокола</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без сжатия адреса/управления</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Отправка эхо-пакетов PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Использовать MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-бит MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Состояние MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Создать PPPoE-соединение</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Системный прокси</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Необязательный</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-прокси</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-прокси</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-прокси</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-прокси</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Игнорировать конфигурации прокси для указанных хостов и доменов</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL-адрес конфигурации</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Туннельный TLS </translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Защищенный EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Сохранить пароль для этого пользователя</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Сохранить пароль для всех пользователей</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Спрашивать меня всегда</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Анонимный</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Проверенный</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Оба</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Версия 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Версия 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP аутентификация</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Идентично</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметры пароля</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Личный ключ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертификат CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертификат пользователя</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Анонимный ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Резервирование</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC файл</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Внутренняя аутентификация</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Версия PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Личный пароль</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Неверный пароль</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>Персональный WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Требуется безопасность</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Неверный пароль</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>Персональный WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>Корпоративный WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Общий ключ</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Открытая система</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Расширенный VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Настройка порта шлюза</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Порт шлюза</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Настроить интервал повторного согласования</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Интервал повторного согласования</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Использовать сжатие данных LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Использовать TCP-соединение</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Использовать устройство TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Настроить MTU туннель</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Настроить размер фрагмента UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Размер фрагмента UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Ограничить туннель TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Случайные удаленные хосты</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Расширенный VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (по умолчанию)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Безопасный (по умолчанию)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Слабый</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T когда доступен (по умолчанию)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T всегда</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Группа DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Группа DH 2 (по умолчанию)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Группа DH 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Сервер (по умолчанию)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Группа DH 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Домен</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Поставщик</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Шифрование</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Режим обхода NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Группа IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Прямая секретность</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Локальный порт</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Отключить обнаружение нерабочих пиров</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Влючить IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Имя группы</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID группы</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Общий ключ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 Алгоритмы</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 Алгоритмы</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертификат CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Разрешить троян Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD скрипт</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертификат пользователя</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Личный ключ</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Использовать FSID для ключевой фразы пароля</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Сертификаты (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Сертификаты с паролем (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Статический ключ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Сохраненный</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Спрашивать</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не требуется</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип аутентификации</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертификат CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертификат пользователя</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Личный ключ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметры пароля</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Личный пароль</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Настроить ключевое направление</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Ключевое направление</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Удаленный IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Локальный IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Доступно всё (по умолчанию)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-бит (менее безопасно)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-бит (более безопасно)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Отказ EAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Отказ PAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Отказ CHAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Отказ MSCHAP-аутентификации</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Отказ MSCHAPv2-аутентификации</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Без сжатия данных BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Без сжатия данных Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без сжатия заголовка TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Без сжатия поля протокола</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без сжатия адреса/управления</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Отправка эхо-пакетов PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Использовать MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Состояние MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Статус VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Создать VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Импортировать VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Ошибка импорта</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Ошибка файла</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-прокси</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не требуется</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP сервера</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Повторять бесконечно при неудаче</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA файл</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Игнорировать предупреждения сертификата</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Использовать TLS расширение имени хоста</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Безопасность VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Шифр</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC-аутентификация</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Сохраненный</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Спрашивать</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не требуется</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметры пароля</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT домен</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-прокси</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP сервера</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Личный ключ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Агент SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Смарт-карта</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Общий ключ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертификат CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип аутентификации</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертификат пользователя</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Запрос внутреннего IP-ареса</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Соблюдать UDP-инкапсуляцию</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Использовать IP-сжатие</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Включить предложения пользовательских шифров</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS аутентификация</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Клиент</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Тематическое Совпадение</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Тип удаленного сертификата</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Файл ключа</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Настроить ключевое направление</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Ключевое направление</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Неверный шлюз</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Сохраненный</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Спрашивать</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не требуется</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметры пароля</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Имя группы</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Групповой пароль</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Использовать гибридную аутентификацию</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA файл</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Сначала подключите сетевой кабель</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Сетевая Карта</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Добавить Сетевое Подключение</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Выберите Настройки</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Адаптер беспроводной сети</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Закрыть точку доступа</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Сначала отключите точку доступа, если вы хотите подключиться к беспроводной сети</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Подключиться к скрытой сети</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не связывать</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Требуется</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC-адрес устройства</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Настроить MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступа</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Тип безопасности</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Диапазон</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска сети</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основной DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорость</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Устройство отключено</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, без доступа к Интернету</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Получение IP адреса</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Подключено</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Получение адреса</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Проводная сеть %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Беспроводная сеть %1</translation>
    </message>
</context>
</TS>